@@ -94,12 +94,20 @@ const Overpass = new Lang.Class({
             place.name = element.tags.name;
         if (element.tags.population)
             place.population = element.tags.population;
+        if (element.tags.website)
+            place.website = element.tags.website;
+        if (element.tags.phone)
+            place.phone = element.tags.phone;
         if (element.tags.wikipedia)
             place.wiki = element.tags.wikipedia;
         if (element.tags.wheelchair)
             place.wheelchair = element.tags.wheelchair;
         if (element.tags.opening_hours)
             place.openingHours = element.tags.opening_hours;
+        if (element.tags.internet_access)
+            place.internetAccess = element.tags.internet_access;
+        if (element.tags.ele && place.location)
+            place.location.altitude = parseFloat(element.tags.ele);
     },
 
     _getQueryUrl: function(place) {
